summaryrefslogtreecommitdiff
path: root/innobase/ha
diff options
context:
space:
mode:
authormarko@hundin.mysql.fi <>2004-04-06 16:14:43 +0300
committermarko@hundin.mysql.fi <>2004-04-06 16:14:43 +0300
commit6af38c65bebe79e36aaa57c0b4f9a78f047bccad (patch)
treef7bc427aa7ce4a54802d6e8931ca1dfe64c7bfa8 /innobase/ha
parent4f9b59f71db750cc2d14b0ed3a910b23996a9032 (diff)
downloadmariadb-git-6af38c65bebe79e36aaa57c0b4f9a78f047bccad.tar.gz
InnoDB: send diagnostic output to stderr or files
instead of stdout or fixed-size memory buffers
Diffstat (limited to 'innobase/ha')
-rw-r--r--innobase/ha/ha0ha.c14
1 files changed, 5 insertions, 9 deletions
diff --git a/innobase/ha/ha0ha.c b/innobase/ha/ha0ha.c
index 483fac4d8cf..c7c4fd46dc8 100644
--- a/innobase/ha/ha0ha.c
+++ b/innobase/ha/ha0ha.c
@@ -264,18 +264,13 @@ Prints info of a hash table. */
void
ha_print_info(
/*==========*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end,/* in: buffer end */
+ FILE* file, /* in: file where to print */
hash_table_t* table) /* in: hash table */
{
hash_cell_t* cell;
ulint cells = 0;
ulint n_bufs;
ulint i;
-
- if (buf_end - buf < 200) {
- return;
- }
for (i = 0; i < hash_get_n_cells(table); i++) {
@@ -287,8 +282,9 @@ ha_print_info(
}
}
- buf += sprintf(buf,
-"Hash table size %lu, used cells %lu", hash_get_n_cells(table), cells);
+ fprintf(file,
+ "Hash table size %lu, used cells %lu",
+ hash_get_n_cells(table), cells);
if (table->heaps == NULL && table->heap != NULL) {
@@ -301,6 +297,6 @@ ha_print_info(
n_bufs++;
}
- buf += sprintf(buf, ", node heap has %lu buffer(s)\n", n_bufs);
+ fprintf(file, ", node heap has %lu buffer(s)\n", n_bufs);
}
}